@@ -6,7 +6,7 @@
  * Largo Pontecorvo 5                                         *
  * 56127 Pisa                                                 *
  * Italy                                                      *
- * Version 1.2 - Nov 2006                                     *
+ * Version 1.3 - March 2007                                   *
  **************************************************************
  *
  *  interfaces.c  -  main window, examples window interfaces
@@ -68,6 +68,7 @@ create_window_main (void)
   GtkWidget *separator11;
   GtkWidget *separator12;
   GtkWidget *separator13;
+  GtkWidget *separator14;
   GtkWidget *menuitem_file;
   GtkWidget *menu_file;
   /* GtkWidget *read_a_m; */
@@ -125,6 +126,12 @@ create_window_main (void)
   GtkWidget *invarsubsp_balzer_m;
   GtkWidget *invarsubsp_schur_m;
 
+  GtkWidget *menuitem_newton;
+  GtkWidget *newton_m;
+  GtkWidget *newton_basic_m;
+  GtkWidget *newton_user_m;
+  GtkWidget *newton_readX_m;
+
   GtkWidget *parameters_cr_m;
   GtkWidget *parameters_lr_m;
   GtkWidget *parameters_fi_m;
@@ -214,6 +221,7 @@ create_window_main (void)
   GSList *funcitera = NULL;
   GSList *funciterb = NULL;
   GSList *invarsubsp = NULL; 
+  GSList *newtongp =NULL;
   GSList *digits = NULL; 
   int i;
   /* all this mess to show the small_star near About Menu end stock_edit near View & Edit A */
@@ -475,6 +483,26 @@ create_window_main (void)
   invarsubsp = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (invarsubsp_schur_m));
   gtk_widget_show (invarsubsp_schur_m);
   gtk_container_add (GTK_CONTAINER (GTK_MENU (invarsubsp_m)),invarsubsp_schur_m);
+  menuitem_newton = gtk_radio_menu_item_new_with_label (algorithms,"Newton Iteration");
+  algorithms = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (menuitem_newton));
+  gtk_widget_show(menuitem_newton);
+  gtk_container_add (GTK_CONTAINER (menu_algorithms), menuitem_newton);
+  newton_m = gtk_menu_new ();
+  gtk_menu_item_set_submenu (GTK_MENU_ITEM (menuitem_newton),newton_m);
+  newton_basic_m=gtk_radio_menu_item_new_with_label(newtongp ,"standard starting point");
+  newtongp = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (newton_basic_m));
+  gtk_widget_show(newton_basic_m);
+  gtk_container_add (GTK_CONTAINER (newton_m), newton_basic_m);
+  newton_user_m=gtk_radio_menu_item_new_with_label(newtongp ,"user's starting point");
+  newtongp = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (newton_user_m));
+  gtk_widget_show(newton_user_m);
+  gtk_container_add (GTK_CONTAINER (newton_m), newton_user_m);
+  separator14 = gtk_separator_menu_item_new();
+  gtk_widget_show(separator14);
+  gtk_container_add (GTK_CONTAINER (newton_m), separator14);
+  newton_readX_m=gtk_menu_item_new_with_label ("Read X(0) from file");
+  gtk_widget_show(newton_readX_m);
+  gtk_container_add (GTK_CONTAINER (newton_m), newton_readX_m); 
 
   separator7 =  gtk_separator_menu_item_new();
   gtk_widget_show(separator7);
@@ -1296,9 +1324,9 @@ if(es[e_n].is_alpha==1) {
         alpha_label = gtk_label_new ("  alpha =");
         gtk_widget_show (alpha_label);
         gtk_box_pack_start (GTK_BOX (hbox), alpha_label, FALSE, FALSE, 0);
-alpha_entry =gtk_entry_new_with_max_length (16);
-gtk_entry_set_width_chars (GTK_ENTRY(alpha_entry),20);
-sprintf(buf,"%.8E",alpha_in);
+alpha_entry =gtk_entry_new_with_max_length (10);
+gtk_entry_set_width_chars (GTK_ENTRY(alpha_entry),13);
+sprintf(buf,"%.4E",alpha_in);
 gtk_entry_set_text(GTK_ENTRY(alpha_entry),buf);
 /*
         alpha_adj = gtk_adjustment_new ((gdouble)alpha_in_mant,(gdouble)-9.999999,(gdouble)9.999999,(gdouble)0.000001,(gdouble)0.001,(gdouble)0.5);
@@ -1326,9 +1354,9 @@ if(es[e_n].is_beta==1) {
         beta_label = gtk_label_new ("   beta =");
         gtk_widget_show (beta_label);
         gtk_box_pack_start (GTK_BOX (hbox), beta_label, FALSE, FALSE, 0);
-beta_entry =gtk_entry_new_with_max_length (16);
-gtk_entry_set_width_chars (GTK_ENTRY(beta_entry),20);
-sprintf(buf,"%.8E",beta_in);
+beta_entry =gtk_entry_new_with_max_length (10);
+gtk_entry_set_width_chars (GTK_ENTRY(beta_entry),13);
+sprintf(buf,"%.4E",beta_in);
 gtk_entry_set_text(GTK_ENTRY(beta_entry),buf);
 /*
         beta_adj = gtk_adjustment_new ((gdouble)beta_in_mant,(gdouble)-9.999999,(gdouble)9.999999,(gdouble)0.000001,(gdouble)0.001,(gdouble)0.5);
