@@ -15,7 +15,11 @@ debug=.false.
 verb=.true.
 !verb=.false.
 
- open(file='Examples/usedA',unit=2)
+write(*,*)
+write(*,*) "This is a sample program that calls some subroutines of the library libsmcsolver.a"
+write(*,*)
+write(*,*) "Reading data file from Examples/usedA"
+open(file='Examples/usedA',unit=2)
 read(2,*)m
 read(2,*)m,m
 allocate(a(m,m,3),g(m,m),x0(m,m))
@@ -27,6 +31,9 @@ read(2,*)m,m
  read(2,*) A(:,:,2)
 read(2,*)m,m
  read(2,*) A(:,:,3)
+
+write(*,*) "done...beginning computations: we shall call subroutine fi"
+write(*,*)
 !do j=1,m
 !   do i=1,m
 !         read(2,*) A(:,:,1)
@@ -58,7 +65,7 @@ x0=0.d0
 ds=.false.
 method = 1
 myeps=1.e-12
-itermax = 1000
+itermax = 200
 
 
 call fi(A=A, doshift=ds, method=method, eps=myeps, maxit=itermax, x0=X0, G=G, &
@@ -66,6 +73,7 @@ drift=drift, err=norm1)
 
 write(*,*)"drift=",drift,"error=",norm1
 
+write(*,*) "now we print the matrix G"
 do i=1,m
   do j=1,m
   write(*,*) "G(",i,j,")=",G(i,j)
